Change in osmo-bts[rel-1.3.2]: osmo-bts-trx: cosmetic: s/trx_sched_fn/bts_sched_fn/g

This is merely a historical archive of years 2008-2021, before the migration to mailman3.

A maintained and still updated list archive can be found at https://lists.osmocom.org/hyperkitty/list/gerrit-log@lists.osmocom.org/.

fixeria gerrit-no-reply at lists.osmocom.org
Wed May 19 20:11:29 UTC 2021


fixeria has uploaded this change for review. ( https://gerrit.osmocom.org/c/osmo-bts/+/24305 )


Change subject: osmo-bts-trx: cosmetic: s/trx_sched_fn/bts_sched_fn/g
......................................................................

osmo-bts-trx: cosmetic: s/trx_sched_fn/bts_sched_fn/g

Change-Id: I47e05b5b3f586430aa0b56c3d3c9a1da23077513
---
M src/osmo-bts-trx/scheduler_trx.c
1 file changed, 5 insertions(+), 5 deletions(-)



  git pull ssh://gerrit.osmocom.org:29418/osmo-bts refs/changes/05/24305/1

diff --git a/src/osmo-bts-trx/scheduler_trx.c b/src/osmo-bts-trx/scheduler_trx.c
index bf0650d..b4ffe52 100644
--- a/src/osmo-bts-trx/scheduler_trx.c
+++ b/src/osmo-bts-trx/scheduler_trx.c
@@ -94,7 +94,7 @@
 }
 
 /* schedule all frames of all TRX for given FN */
-static void trx_sched_fn(struct gsm_bts *bts, const uint32_t fn)
+static void bts_sched_fn(struct gsm_bts *bts, const uint32_t fn)
 {
 	struct trx_dl_burst_req br;
 	struct gsm_bts_trx *trx;
@@ -306,9 +306,9 @@
 		goto no_clock;
 	}
 
 	/* call trx_sched_fn() for all expired FN */
 	for (i = 0; i < expire_count; i++)
-		trx_sched_fn(bts, GSM_TDMA_FN_INC(tcs->last_fn_timer.fn));
+		bts_sched_fn(bts, GSM_TDMA_FN_INC(tcs->last_fn_timer.fn));
 
 	return 0;
 
@@ -371,7 +371,7 @@
 {
 	tcs->last_fn_timer.fn = fn;
 	/* call trx cheduler function for new 'last' FN */
-	trx_sched_fn(bts, tcs->last_fn_timer.fn);
+	bts_sched_fn(bts, tcs->last_fn_timer.fn);
 
 	/* schedule first FN clock timer */
 	osmo_timerfd_setup(&tcs->fn_timer_ofd, trx_fn_timer_cb, bts);
@@ -454,7 +454,7 @@
 
 	/* transmit what we still need to transmit */
 	while (fn != tcs->last_fn_timer.fn) {
-		trx_sched_fn(bts, GSM_TDMA_FN_INC(tcs->last_fn_timer.fn));
+		bts_sched_fn(bts, GSM_TDMA_FN_INC(tcs->last_fn_timer.fn));
 		fn_caught_up++;
 	}
 
@@ -306,9 +306,9 @@
 	}
 
-	/* call trx_sched_fn() for all expired FN */
+	/* call bts_sched_fn() for all expired FN */
 	for (i = 0; i < expire_count; i++)

-- 
To view, visit https://gerrit.osmocom.org/c/osmo-bts/+/24305
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bts
Gerrit-Branch: rel-1.3.2
Gerrit-Change-Id: I47e05b5b3f586430aa0b56c3d3c9a1da23077513
Gerrit-Change-Number: 24305
Gerrit-PatchSet: 1
Gerrit-Owner: fixeria <vyanitskiy at sysmocom.de>
Gerrit-MessageType: newchange
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.osmocom.org/pipermail/gerrit-log/attachments/20210519/2472329f/attachment.htm>


More information about the gerrit-log mailing list